summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
index f8b4798c..540d774d 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
@@ -51,9 +51,9 @@ class CaptchaChallenge;
//
/////////////////////////////////////////////////////////////////////
//
// See Task first. XmppClient is a parent task for XmppTasks.
//
// XmppClient is a task which is designed to be the parent task for
// all tasks that depend on a single Xmpp connection. If you want to,
// for example, listen for subscription requests forever, then your
// listener should be a task that is a child of the XmppClient that owns
@@ -71,17 +71,17 @@ class CaptchaChallenge;
class XmppClient : public Task, public sigslot::has_slots<>
{
public:
- XmppClient(Task * parent);
+ XmppClient(Task * tqparent);
~XmppClient();
- XmppReturnStatus Connect(const XmppClientSettings & settings,
+ XmppReturntqStatus Connect(const XmppClientSettings & settings,
AsyncSocket * socket,
PreXmppAuth * preauth);
virtual Task * GetParent(int code);
virtual int ProcessStart();
virtual int ProcessResponse();
- XmppReturnStatus Disconnect();
+ XmppReturntqStatus Disconnect();
const Jid & jid();
sigslot::signal1<XmppEngine::State> SignalStateChange;
@@ -97,9 +97,9 @@ public:
std::string GetAuthCookie();
std::string NextId();
- XmppReturnStatus SendStanza(const XmlElement *stanza);
- XmppReturnStatus SendRaw(const std::string & text);
- XmppReturnStatus SendStanzaError(const XmlElement * pelOriginal,
+ XmppReturntqStatus SendStanza(const XmlElement *stanza);
+ XmppReturntqStatus SendRaw(const std::string & text);
+ XmppReturntqStatus SendStanzaError(const XmlElement * pelOriginal,
XmppStanzaError code,
const std::string & text);
@@ -51,9 +51,9 @@ class CaptchaChallenge;
/////////////////////////////////////////////////////////////////////
//
-// See Task first. XmppClient is a parent task for XmppTasks.
+// See Task first. XmppClient is a tqparent task for XmppTasks.
//
@@ -51,9 +51,9 @@ class CaptchaChallenge;
//
-// XmppClient is a task which is designed to be the parent task for
+// XmppClient is a task which is designed to be the tqparent task for
// all tasks that depend on a single Xmpp connection. If you want to,
// for example, listen for subscription requests forever, then your